@@ -24,6 +24,7 @@
 
 #include <KIconLoader>
 #include <KActionCollection>
+#include <QAction>
 
 #include <QTextCursor>
 #include <qtestevent.h>
@@ -473,6 +474,24 @@ void RichTextComposerTest::testWrappedPlainText()
     QCOMPARE(edit.composerControler()->toWrappedPlainText(), text);
 }
 
+void RichTextComposerTest::testEnableDisableActions()
+{
+    KPIMTextEdit::RichTextComposer composer;
+    KActionCollection *actionCollection = new KActionCollection(&composer);
+    composer.createActions(actionCollection);
+    bool enableAction = true;
+    composer.setEnableActions(enableAction);
+    Q_FOREACH (QAction *act, composer.actions()) {
+        QCOMPARE(act->isEnabled(), enableAction);
+    }
+
+    enableAction = false;
+    composer.setEnableActions(enableAction);
+    Q_FOREACH (QAction *act, composer.actions()) {
+        QCOMPARE(act->isEnabled(), enableAction);
+    }
+}
+
 void RichTextComposerTest::shouldHaveDefaultValue()
 {
     KPIMTextEdit::RichTextComposer composer;
