@@ -96,7 +96,7 @@ Q_SIGNALS:
 public Q_SLOTS:
     void slotDisplayMessageIndicator(const QString &message);
     void slotSpeakText();
-    void slotCheckSpelling();    
+    void slotCheckSpelling();
     void slotZoomReset();
 
 private Q_SLOTS:
@@ -135,8 +135,8 @@ Q_SIGNALS:
 
 private:
     void addIgnoreWordsToHighLighter();
-    bool handleShortcut(const QKeyEvent *event);
-    bool overrideShortcut(const QKeyEvent *event);
+    bool handleShortcut(QKeyEvent *event);
+    bool overrideShortcut(QKeyEvent *event);
     void deleteWordBack();
     void deleteWordForward();
     void highlightWord(int length, int pos);
